@@ -1,8 +1,8 @@
 package Net::IPAddress::Util::Range;
 
-use 5.010000;
-use strict;
-use warnings;
+use 5.012000;
+use utf8;
+
 use overload (
     '""' => 'as_string',
     '<=>' => 'spaceship',
@@ -158,6 +158,16 @@ sub tight {
     return $rv;
 }
 
+sub lower {
+    my $self = shift;
+    return $self->{ lower };
+}
+
+sub upper {
+    my $self = shift;
+    return $self->{ upper };
+}
+
 1;
 
 __END__
